summaryrefslogtreecommitdiffstats
path: root/buildtools/qmake/trollprojectwidget.h
diff options
context:
space:
mode:
Diffstat (limited to 'buildtools/qmake/trollprojectwidget.h')
-rw-r--r--buildtools/qmake/trollprojectwidget.h124
1 files changed, 62 insertions, 62 deletions
diff --git a/buildtools/qmake/trollprojectwidget.h b/buildtools/qmake/trollprojectwidget.h
index 19595f78..7983f4d7 100644
--- a/buildtools/qmake/trollprojectwidget.h
+++ b/buildtools/qmake/trollprojectwidget.h
@@ -20,18 +20,18 @@
#ifndef _TROLLPROJECTWIDGET_H_
#define _TROLLPROJECTWIDGET_H_
-#include <qdict.h>
-#include <qlistview.h>
-#include <qmap.h>
-#include <qstrlist.h>
-#include <qvbox.h>
-#include <qtoolbutton.h>
+#include <tqdict.h>
+#include <tqlistview.h>
+#include <tqmap.h>
+#include <tqstrlist.h>
+#include <tqvbox.h>
+#include <tqtoolbutton.h>
#include <kiconloader.h>
#include <klocale.h>
#include <kdeversion.h>
-#include <qbutton.h>
-#include <qfileinfo.h>
-#include <qptrlist.h>
+#include <tqbutton.h>
+#include <tqfileinfo.h>
+#include <tqptrlist.h>
#include "choosesubprojectdlg.h"
#include "newwidgetdlg.h"
#include "domutil.h"
@@ -49,45 +49,45 @@ public:
TrollProjectWidget( TrollProjectPart *part );
~TrollProjectWidget();
- void openProject( const QString &dirName );
+ void openProject( const TQString &dirName );
void closeProject();
/**
* A list of the (relative) names of all subprojects (== subdirectories).
*/
- //QStringList allSubprojects();
+ //TQStringList allSubprojects();
/**
* A list of the (relative) names of all libraries.
*/
- QStringList allLibraries();
+ TQStringList allLibraries();
/**
* A list of all files that belong to the project.
**/
- QStringList allFiles();
+ TQStringList allFiles();
/**
* The top level directory of the project.
**/
- QString projectDirectory();
+ TQString projectDirectory();
/**
* The directory of the currently active subproject.
*/
- QString subprojectDirectory();
+ TQString subprojectDirectory();
/**
* The directory of the currently active subproject.
*/
- QString getCurrentTarget();
+ TQString getCurrentTarget();
- QString getCurrentDestDir();
+ TQString getCurrentDestDir();
- QString getCurrentOutputFilename();
+ TQString getCurrentOutputFilename();
- void addFileToCurrentSubProject( GroupItem *titem, const QString &filename );
- void addFileToCurrentSubProject( GroupItem::GroupType gtype, const QString &filename );
- void addFiles( QStringList &files, bool relativeToProjectRoot = true );
- void emitAddedFile( const QString &name );
- void emitRemovedFile( const QString &name );
+ void addFileToCurrentSubProject( GroupItem *titem, const TQString &filename );
+ void addFileToCurrentSubProject( GroupItem::GroupType gtype, const TQString &filename );
+ void addFiles( TQStringList &files, bool relativeToProjectRoot = true );
+ void emitAddedFile( const TQString &name );
+ void emitRemovedFile( const TQString &name );
- QString getUiFileLink( const QString &path, const QString& filename );
+ TQString getUiFileLink( const TQString &path, const TQString& filename );
bool isTMakeProject();
enum TrollProjectView { SubprojectView, DetailsView };
@@ -122,78 +122,78 @@ public slots:
void slotRemoveFile();
protected:
- virtual void focusInEvent( QFocusEvent *e );
+ virtual void focusInEvent( TQFocusEvent *e );
private slots:
- void slotOverviewSelectionChanged( QListViewItem *item );
- void slotOverviewContextMenu( KListView *, QListViewItem *item, const QPoint &p );
- void slotDetailsSelectionChanged( QListViewItem* );
- void slotDetailsExecuted( QListViewItem *item );
- void slotDetailsContextMenu( KListView *, QListViewItem *item, const QPoint &p );
+ void slotOverviewSelectionChanged( TQListViewItem *item );
+ void slotOverviewContextMenu( KListView *, TQListViewItem *item, const TQPoint &p );
+ void slotDetailsSelectionChanged( TQListViewItem* );
+ void slotDetailsExecuted( TQListViewItem *item );
+ void slotDetailsContextMenu( KListView *, TQListViewItem *item, const TQPoint &p );
void slotExcludeFileFromScopeButton();
void slotAddSubproject( QMakeScopeItem *spitem = 0 );
void slotRemoveSubproject( QMakeScopeItem *spitem = 0 );
void slotCreateScope( QMakeScopeItem *spitem = 0 );
void slotRemoveScope( QMakeScopeItem *spitem = 0 );
void slotDisableSubproject( QMakeScopeItem* spitem = 0 );
- void slotProjectDirty( const QString& );
+ void slotProjectDirty( const TQString& );
void createQMakeScopeItems();
private:
void cleanDetailView( QMakeScopeItem *item );
- void runClean( QMakeScopeItem*, const QString& );
+ void runClean( QMakeScopeItem*, const TQString& );
void buildProjectDetailTree( QMakeScopeItem *item, KListView *listviewControl );
void removeFile( QMakeScopeItem *spitem, FileItem *fitem );
- void addSubprojectToItem( QMakeScopeItem*, const QString& );
+ void addSubprojectToItem( QMakeScopeItem*, const TQString& );
void setupContext();
- // void parseScope(QMakeScopeItem *item,QString scopeString, Scope *scope);
+ // void parseScope(QMakeScopeItem *item,TQString scopeString, Scope *scope);
GroupItem* getInstallRoot( QMakeScopeItem *item );
- GroupItem* getInstallObject( QMakeScopeItem *item, const QString& objectname );
- QString constructMakeCommandLine( Scope* s = 0 );
+ GroupItem* getInstallObject( QMakeScopeItem *item, const TQString& objectname );
+ TQString constructMakeCommandLine( Scope* s = 0 );
- void createMakefileIfMissing( const QString &dir, QMakeScopeItem *item );
+ void createMakefileIfMissing( const TQString &dir, QMakeScopeItem *item );
void runQMakeRecursive( QMakeScopeItem* proj);
void buildFile( QMakeScopeItem* spitem, FileItem* fitem);
- /*fileName: full base file name like QFileInfo::baseName ( true )*/
- QPtrList<QMakeScopeItem> findSubprojectForFile( QFileInfo fi );
- void findSubprojectForFile( QPtrList<QMakeScopeItem> &list, QMakeScopeItem * item, QString absFilePath );
- QMakeScopeItem* findSubprojectForPath( const QString& );
- // QString makeEnvironment();
+ /*fileName: full base file name like TQFileInfo::baseName ( true )*/
+ TQPtrList<QMakeScopeItem> findSubprojectForFile( TQFileInfo fi );
+ void findSubprojectForFile( TQPtrList<QMakeScopeItem> &list, QMakeScopeItem * item, TQString absFilePath );
+ QMakeScopeItem* findSubprojectForPath( const TQString& );
+ // TQString makeEnvironment();
TrollProjectWidget::SaveType dialogSaveBehaviour() const;
QMakeScopeItem *findSubprojectForScope( QMakeScopeItem *scope );
void reloadProjectFromFile( QMakeScopeItem* item );
- QMap<QString,QString> qmakeEnvironment() const;
+ TQMap<TQString,TQString> qmakeEnvironment() const;
- QVBox *overviewContainer;
+ TQVBox *overviewContainer;
KListView *overview;
- QHBox *projectTools;
- QToolButton *addSubdirButton;
- QToolButton *createScopeButton;
+ TQHBox *projectTools;
+ TQToolButton *addSubdirButton;
+ TQToolButton *createScopeButton;
- QToolButton *buildProjectButton;
- QToolButton *rebuildProjectButton;
- QToolButton *executeProjectButton;
+ TQToolButton *buildProjectButton;
+ TQToolButton *rebuildProjectButton;
+ TQToolButton *executeProjectButton;
- QToolButton *buildTargetButton;
- QToolButton *rebuildTargetButton;
- QToolButton *executeTargetButton;
+ TQToolButton *buildTargetButton;
+ TQToolButton *rebuildTargetButton;
+ TQToolButton *executeTargetButton;
- QToolButton *buildFileButton;
- QToolButton *projectconfButton;
+ TQToolButton *buildFileButton;
+ TQToolButton *projectconfButton;
- QVBox *detailContainer;
+ TQVBox *detailContainer;
KListView *details;
- QHBox *fileTools;
- QToolButton *addfilesButton;
- QToolButton *newfileButton;
- QToolButton *removefileButton;
- QToolButton *excludeFileFromScopeButton;
+ TQHBox *fileTools;
+ TQToolButton *addfilesButton;
+ TQToolButton *newfileButton;
+ TQToolButton *removefileButton;
+ TQToolButton *excludeFileFromScopeButton;
DomUtil::PairList m_subclasslist;
QMakeScopeItem *m_shownSubproject;
@@ -207,7 +207,7 @@ private:
bool m_filesCached;
bool m_showFilenamesOnly;
bool m_showVariablesInTree;
- QStringList m_allFilesCache;
+ TQStringList m_allFilesCache;
friend class ChooseSubprojectDlg;
friend class ProjectConfigurationDlg;